@@ -111,6 +111,7 @@ _format_defanged_domain = (
     R'[a-zA-Z0-9\_][a-zA-Z0-9\-\_]{{1,62}}(?:\[\.\]|\.){tlds}'
 )
 
+_pattern_utf8 = R'(?:[\x00-\x7F]|[\xC0-\xDF][\x80-\xBF]|[\xE0-\xEF][\x80-\xBF]{2}|[\xF0-\xF7][\x80-\xBF]{3})+'
 
 _pattern_serrated_domain = _format_serrated_domain.format(repeat='{0,20}', tlds=_TLDS)
 _pattern_defanged_domain = _format_defanged_domain.format(repeat='{0,20}', tlds=_TLDS)
@@ -155,6 +156,8 @@ _pattern_cmdstr = R'''(?:"(?:""|[^"])*"|'(?:''|[^'])*')'''
 _pattern_ps1str = R'''(?:@"\s*?[\r\n].*?[\r\n]"@|@'\s*?[\r\n].*?[\r\n]'@|"(?:`.|""|[^"])*"|'(?:''|[^'])*')'''
 
 _pattern_string = R'''(?:"(?:[^"\\]|\\.)*"|'(?:[^'\\]|\\.)*')'''
+_pattern_urlenc_hard = R'''(?:%[0-9a-fA-F]{2}|[0-9a-zA-Z\-\._~\?!$&=:\/#\[\]@'\(\)\*\+,;])+'''
+_pattern_urlenc_soft = R'''(?:%[0-9a-fA-F]{2}|[0-9a-zA-Z\-\._~\?!$&=])+'''
 
 _pattern_vbe = R'''#@~\^[ -~]{6}==(?:.*?)[ -~]{6}==\^#~@'''
 
@@ -238,6 +241,10 @@ class formats(PatternEnum):
     "PowerShell escaped string literal"
     printable = alphabet(R'[ -~]')
     "Any sequence of printable characters"
+    urlencstrict = pattern(_pattern_urlenc_hard)
+    "Any sequence of url-encoded characters"
+    urlenc = pattern(_pattern_urlenc_soft)
+    "Any sequence of url-encoded characters"
     intarray = tokenize(_pattern_integer, sep=R'\s*[;,]\s*', bound='')
     "Sequences of integers, separated by commas or semicolons"
     word = alphabet(R'\\w')
@@ -252,12 +259,14 @@ class formats(PatternEnum):
     "Base32 encoded strings"
     b64 = alphabet(R'[0-9a-zA-Z\+\/]', postfix=R'[0-9a-zA-Z\+\/]{0,3}={0,3}')
     "Base64 encoded strings"
-    b64u = alphabet(R'[0-9a-zA-Z\_\-]', postfix=R'[0-9a-zA-Z\_\-]{0,3}={0,3}')
+    b64url = alphabet(R'[0-9a-zA-Z\_\-]', postfix=R'[0-9a-zA-Z\_\-]{0,3}={0,3}')
     "Base64 encoded strings using URL-safe alphabet"
     hex = alphabet(R'[0-9a-fA-F]')
     "Hexadecimal strings"
     HEX = alphabet(R'[0-9A-F]')
     "Uppercase hexadecimal strings"
+    utf8 = pattern(_pattern_utf8)
+    "A sequence of bytes that can be decoded as UTF8."
     hexdump = tokenize(_pattern_hexline, bound='', sep=R'\s*\n')
     """
     This pattern matches a typical hexdump output where hexadecimally encoded
