@@ -6,34 +6,20 @@ Miscellaneous helper functions.
 import inspect
 import itertools
 import functools
+import logging
 import os
 import sys
 
-from typing import ByteString, Iterable
+from typing import ByteString, Iterable, TypeVar
 from math import log
 
 
-def format_size(num: int, align=False) -> str:
-    """
-    Given a number of bytes, produce a human-readable expression for this
-    size using common units such as kB and MB.
-    """
-    step = 1000.0
-    unit = None
-    result = num
-    for unit in [None, 'kB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB']:
-        if unit and result / step <= 0.1:
-            break
-        result /= step
-    if unit is None:
-        width = 3 if align else ''
-        return F'{result:{width}} BYTES'
-    else:
-        width = 6 if align else ''
-        return F'{result:{width}.3f} {unit}'
+_T = TypeVar('_T')
+_D = TypeVar('_D')
 
 
-format_size.width = 9
+def _singleton(cls):
+    return cls()
 
 
 def lookahead(iterator):
@@ -61,16 +47,23 @@ def get_terminal_size():
     """
     Returns the size of the currently attached terminal. If the environment variable
     `REFINERY_TERMSIZE` is set to an integer value, it takes prescedence. If the width
-    of the terminal cannot be determined, the function returns zero.
+    of the terminal cannot be determined of if the width is less than 8 characters,
+    the function returns zero.
     """
     try:
         return int(os.environ['REFINERY_TERMSIZE'])
     except (KeyError, ValueError):
         pass
     try:
-        return os.get_terminal_size(sys.stderr.fileno()).columns - 1
+        err_width = os.get_terminal_size(sys.stderr.fileno()).columns
     except OSError:
-        return 0
+        err_width = 0
+    try:
+        out_width = os.get_terminal_size(sys.stdout.fileno()).columns
+    except OSError:
+        out_width = 0
+    width = max(err_width, out_width)
+    return 0 if width < 9 else width - 1
 
 
 def terminalfit(text: str, delta: int = 0, width: int = 0, **kw) -> str:
@@ -160,9 +153,18 @@ def autoinvoke(method, keywords: dict):
         try:
             value = keywords.pop(p.name)
         except KeyError:
-            continue
-        if p.kind in (p.POSITIONAL_ONLY, p.POSITIONAL_OR_KEYWORD):
+            if p.kind is p.VAR_KEYWORD:
+                continue
+            value = p.default
+            if value is p.empty:
+                raise ValueError(F'missing required parameter {p.name}')
+        if p.kind is p.POSITIONAL_OR_KEYWORD or p.kind is p.POSITIONAL_ONLY:
+            if value == p.default:
+                # when equality holds, we force identity
+                value = p.default
             posargs.append(value)
+        elif p.default == value:
+            continue
         elif p.kind is p.VAR_POSITIONAL:
             varargs = value
         elif p.kind is p.KEYWORD_ONLY:
@@ -194,6 +196,10 @@ def entropy(data: bytearray) -> float:
         return 0.0 + -sum(p * log(p, 2) for p in probs) / 8.0
 
 
+def isstream(obj) -> bool:
+    return hasattr(obj, 'read')
+
+
 def isbuffer(obj) -> bool:
     """
     Test whether `obj` is an object that supports the buffer API, like a bytes
@@ -242,3 +248,27 @@ def infinitize(it):
 
 def cached_property(p):
     return property(functools.lru_cache(maxsize=1)(p))
+
+
+@_singleton
+class NoLogging:
+    def __enter__(self):
+        logging.disable(logging.CRITICAL)
+        return self
+
+    def __exit__(self, *_):
+        logging.disable(logging.NOTSET)
+
+
+def one(iterable: Iterable[_T]) -> _T:
+    it = iter(iterable)
+    try:
+        top = next(it)
+    except StopIteration:
+        raise LookupError
+    try:
+        next(it)
+    except StopIteration:
+        return top
+    else:
+        raise LookupError
