@@ -128,7 +128,7 @@ from argparse import (
 
 from ..lib.argformats import pending, manifest, multibin, number, sliceobj, VariableMissing
 from ..lib.argparser import ArgumentParserWithKeywordHooks, ArgparseError
-from ..lib.tools import documentation, lookahead, autoinvoke, skipfirst, isbuffer
+from ..lib.tools import documentation, isstream, lookahead, autoinvoke, skipfirst, isbuffer
 from ..lib.frame import Framed, Chunk
 from ..lib.structures import MemoryFile
 
@@ -1084,21 +1084,49 @@ class Unit(UnitBase, abstract=True):
         return copy
 
     def __ror__(self, stream: Union[BinaryIO, ByteString]):
-        if not isbuffer(stream):
+        if isstream(stream):
             self.nozzle.source = stream
             return self
-        return self(stream)
+        with MemoryFile(stream) if stream else open(os.devnull, 'rb') as stdin:
+            return (stdin | self)
+
+    def __str__(self):
+        with MemoryFile() as stdout:
+            return (self | stdout).getbuffer().decode(self.codec)
+
+    def __bytes__(self):
+        with MemoryFile() as stdout:
+            result = bytes((self | stdout).getbuffer())
+        return result
 
     def __or__(self, stream: Union[BinaryIO, Unit]):
-        try:
-            if isinstance(stream, type):
-                stream = stream()
+        if isinstance(stream, type) and issubclass(stream, Entry):
+            stream = stream()
+        if isinstance(stream, Entry):
             return stream.__copy__().__ror__(self)
-        except AttributeError:
-            self._target = stream
+        elif isinstance(stream, list):
+            stream.extend(self)
+            return stream
+        elif isinstance(stream, set):
+            stream.update(self)
+            return stream
+        elif isinstance(stream, dict):
+            if len(stream) == 1:
+                key, check = next(iter(stream.items()))
+                if check is ...:
+                    return {item[key]: item for item in self}
+            raise ValueError('dict consumption target must be of format {"key": ...}')
+        elif isinstance(stream, (bytearray, memoryview)):
+            with MemoryFile(stream) as stdout:
+                return (self | stdout).getvalue()
+        elif callable(stream):
+            with MemoryFile() as stdout:
+                return stream((self | stdout).getvalue())
 
-        if not self._target.writable():
-            return
+        if not stream.writable():
+            raise ValueError('target stream is not writable')
+
+        self._target = stream
 
         def cname(x): return x.lower().replace('-', '')
 
@@ -1118,8 +1146,8 @@ class Unit(UnitBase, abstract=True):
                 except Exception:
                     pass
             try:
-                self._target.write(chunk)
-                self._target.flush()
+                stream.write(chunk)
+                stream.flush()
             except AttributeError:
                 pass
             except (BrokenPipeError, OSError) as E:
@@ -1133,12 +1161,12 @@ class Unit(UnitBase, abstract=True):
 
         try:
             if self.isatty and chunk and not chunk.endswith(B'\n'):
-                self._target.write(B'\n')
-                self._target.flush()
+                stream.write(B'\n')
+                stream.flush()
         except (NameError, AttributeError):
             pass
 
-        return self._target
+        return stream
 
     def read(self, bytecount: int = -1) -> bytes:
         """
