@@ -10,8 +10,8 @@ class repl(Unit):
 
     def __init__(
         self,
-        search : arg.help('This is the search term.'),
-        replace: arg.help('The substitution string. Leave this empty to remove all occurrences of the search term.') = B'',
+        search : arg(help='This is the search term.'),
+        replace: arg(help='The substitution string. Leave this empty to remove all occurrences of the search term.') = B'',
         count  : arg.number('-n', help='Only replace the given number of occurrences') = -1
     ):
         super().__init__(search=search, replace=replace, count=count)
